"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.pluginToken = void 0;
const axios_1 = __importDefault(require("axios"));
function createRequestInterceptor(provider) {
    return async (config) => {
        const token = await provider.getToken();
        if (token) {
            config.headers = {
                ...config.headers,
                Authorization: `Bearer ${token}`,
            };
        }
        return config;
    };
}
function createResponseInterceptor(instance, provider) {
    return async (error) => {
        var _a;
        if (axios_1.default.isAxiosError(error) && provider.renewToken) {
            const retryConfig = error.config;
            if (((_a = error.response) === null || _a === void 0 ? void 0 : _a.status) === 401 && !retryConfig.retried) {
                retryConfig.retried = true;
                provider.renewToken();
                return instance.request(retryConfig);
            }
        }
        throw error;
    };
}
function pluginToken(provider) {
    return (zodios) => {
        zodios.axios.interceptors.request.use(createRequestInterceptor(provider));
        if (provider === null || provider === void 0 ? void 0 : provider.renewToken) {
            zodios.axios.interceptors.response.use(undefined, createResponseInterceptor(zodios.axios, provider));
        }
    };
}
exports.pluginToken = pluginToken;
