import { UseQueryOptions } from "react-query";
import { ZodiosEnpointDescriptions, Paths, ZodiosMethodOptions } from "../zodios.types";
/**
 * React hook to call an api "get" endpoint.
 * It's a thin wrapper for react-query and useContext.
 * It should not be used without wrapping it in another hook @see example
 * else you will not have nice autocompletions in your IDE.
 * It should be used in combination with the ZodiosProvider
 * @param apiName - the name of the api used in Zodios Provider
 * @param path - the path to api endpoint
 * @param config - the config to setup axios options and parameters
 * @param queryOptions - the query options to setup react-query options
 * @returns the response validated with zod
 *
 * @example ```typescript
 *   type Api = ApiOf<typeof myZodiosClient>;
 *   function useJsonPlaceholder<Path extends Paths<Api, "get">>(
 *     path: Path,
 *     config?: ZodiosRequestOptions<Api, "get", Path>
 *   ) {
 *     return useZodios("https://jsonplaceholder.typicode.com", path, config);
 *   }
 * ```
 */
export declare function useZodios<Api extends ZodiosEnpointDescriptions, Path extends Paths<Api, "get">>(apiName: string, path: Path, config?: ZodiosMethodOptions<Api, "get", Path>, queryOptions?: Omit<UseQueryOptions, "queryKey" | "queryFn">): import("react-query").UseQueryResult<Awaited<import("../zodios.types").Response<Api, "get", Path>>, unknown>;
